use crate::{
	files::get_file_wrapper,
	responders::{CachedResponse, RawWoff2Font, RawWoffFont},
};
use rocket::{http::Status, response::content::RawCss};

#[get("/css/<style>")]
pub fn style(style: &str) -> Result<CachedResponse<RawCss<String>>, Status> {
	let style_file = &get_file_wrapper()?.style;
	let hyperlegible_file = &get_file_wrapper()?.hyperlegible;

	let style_name = style_file.metadata.get_hash_filename();
	let hyperlegible_name = hyperlegible_file.metadata.get_hash_filename();

	if style == style_name {
		Ok(RawCss::<String>(style_file.text.clone()).into())
	} else if style == hyperlegible_name {
		Ok(RawCss::<String>(hyperlegible_file.text.clone()).into())
	} else {
		Err(Status::NotFound)
	}
}

#[get("/woff2/<font>")]
pub fn woff2_font(font: &str) -> Result<CachedResponse<RawWoff2Font>, Status> {
	let latin_file = &get_file_wrapper()?.atkinson_latin_woff2;
	let latin_ext_file = &get_file_wrapper()?.atkinson_latin_ext_woff2;

	let latin = latin_file.metadata.get_hash_filename();
	let latin_ext = latin_file.metadata.get_hash_filename();

	if font == latin {
		Ok(RawWoff2Font(latin_file.data.clone()).into())
	} else if font == latin_ext {
		Ok(RawWoff2Font(latin_ext_file.data.clone()).into())
	} else {
		Err(Status::NotFound)
	}
}

#[get("/woff/<font>")]
pub fn woff_font(font: &str) -> Result<CachedResponse<RawWoffFont>, Status> {
	let all_file = &get_file_wrapper()?.atkinson_all_woff;
	let all = all_file.metadata.get_hash_filename();

	if font == all {
		Ok(RawWoffFont(all_file.data.clone()).into())
	} else {
		Err(Status::NotFound)
	}
}
